versuchung - a toolbox for experiments
======================================

In some fields of science it is common practice to not publish any
experiment descriptions or the raw measurement results of the
experiment. This is not only opposed to the idea of science, where
results should be reproducible to verify them by a larger audience,
but also harmful for other researchers, who want to extend the results
in the field.

This lack of experiment descriptions and raw data is not necessary a
result of mean intention by the original researcher, more a lack of
tools for documenting and specifying experiements and the raw data
analysis. This is especially true for some fields of computer
science. But as these people are experts in using formal descriptions
(also known as programming languages) it is surprising that there is
no easy-to-use tool for specifying experiments and analyses.

Versuchung tries to fill this gap, by providing such a tool, where
experiments can be specified with proper input and output parameter
declarations, versioned result sets and the possibility to process the
result sets further.

Documentation
=============

For the documentation, please refer to https://versuchung.readthedocs.io

Getting the latest version
==========================

versuchung is hosted at github: https://github.com/stettberger/versuchung
